/*
 * Copyright (c) 2005-2013, BearWare.dk
 * 
 * Contact Information:
 *
 * Bjoern D. Rasmussen
 * Bedelundvej 79
 * DK-9830 Taars
 * Denmark
 * Email: contact@bearware.dk
 * Phone: +45 20 20 54 59
 * Web: http://www.bearware.dk
 *
 * This source code is part of the TeamTalk 4 SDK owned by
 * BearWare.dk. All copyright statements may not be removed 
 * or altered from any source distribution. If you use this
 * software in a product, an acknowledgment in the product 
 * documentation is required.
 *
 */

#include "uservideodlg.h"
#include "mainwindow.h"

extern TTInstance* ttInst;

UserVideoDlg::UserVideoDlg(int userid, int streamid, const QSize& size, 
                           QWidget * parent/* = 0*/)
: QDialog(parent, Qt::Dialog | Qt::WindowMinMaxButtonsHint | Qt::WindowSystemMenuHint)
, m_autosize(false)
{
    ui.setupUi(this);
    setWindowIcon(QIcon(APPICON));

    this->resize(size);
    ui.uservideoWidget->m_userid = userid;
    ui.uservideoWidget->m_streamid = streamid;
    slotUserUpdate(userid, 0);

    initBackground();
}

UserVideoDlg::UserVideoDlg(int userid, int streamid, QWidget * parent/* = 0*/)
: QDialog(parent, Qt::Dialog | Qt::WindowMinMaxButtonsHint | Qt::WindowSystemMenuHint)
, m_autosize(true)
{
    ui.setupUi(this);
    setWindowIcon(QIcon(APPICON));

    this->resize(QSize(100,100));

    ui.uservideoWidget->m_userid = userid;
    ui.uservideoWidget->m_streamid = streamid;

    slotUserUpdate(userid, 0);

    initBackground();
}

void UserVideoDlg::initBackground()
{
    //set black as background color
    ui.uservideoWidget->setAutoFillBackground(true);
    QPalette p = ui.uservideoWidget->palette();
    p.setBrush(QPalette::Background, QBrush(Qt::black));
    ui.uservideoWidget->setPalette(p);
}

UserVideoDlg::~UserVideoDlg()
{
    emit(userVideoDlgClosing(ui.uservideoWidget->m_userid, 
                             ui.uservideoWidget->m_streamid));
}

void UserVideoDlg::slotUserUpdate(int userid, int /*channelid*/)
{
    if(userid != ui.uservideoWidget->m_userid)
        return;

    if(userid == 0)
        setWindowTitle(tr("Video") + QString(" - ") + tr("Myself"));
    else
    {
        User user;
        if(TT_GetUser(ttInst, userid, &user))
            setWindowTitle(tr("Video") + QString(" - ") + _Q(user.szNickname));
    }
}

void UserVideoDlg::slotNewVideoFrame(int userid, int /*streamid*/)
{
    if(userid != ui.uservideoWidget->m_userid)
        return;

    if(m_autosize)
    {
        this->resize(ui.uservideoWidget->imageSize());
        m_autosize = false;
    }
}
